@@ -55,7 +55,7 @@ debci_sendmail_from="${debci_sendmail_from:-$debci_distro_name Continuous Integr
 debci_sendmail_to="${debci_sendmail_to:-%s@localhost}"
 debci_url_base="${debci_url_base:-http://localhost:8080}"
 debci_artifacts_url_base="${debci_artifacts_url_base:-}"
-debci_database_url="${debci_database_url:-sqlite3://$debci_data_basedir/debci.sqlite3}"
+debci_database_url="${debci_database_url:-sqlite3://$debci_data_basedir/debci.sqlite3?timeout=5000}"
 
 debci_secrets_dir=${debci_secrets_dir:-$(readlink -f "${debci_base_dir}/secrets")}
 
@@ -161,7 +161,7 @@ debci_batch_lock=${debci_lock_dir}/debci-batch-${debci_suite}-${debci_arch}.lock
 debci_generate_index_lock=${debci_lock_dir}/debci-generate-index.lock
 
 # data retention policy (numbers of days)
-debci_data_retention_days=180
+debci_data_retention_days=${debci_data_retention_days:-180}
 
 # extra arguments for autopkgtest
 debci_autopkgtest_args="${debci_autopkgtest_args:-}"
